@@ -1,6 +1,6 @@
 // pngrecolor.c - part of pngrecolor
 // Copyright (C) 2010 by Jason Summers (from original pngrewrite.c)
-// Modifications (C) 2013-2014 by Brian Lindholm
+// Modifications (C) 2013-2020 by Brian Lindholm
 //   [1] Renamed from "pngrewrite" to "pngrecolor" at avoid confusion with
 //       original program.
 //   [2] Modified palette comparison routine to ensure a *unique* sorting.
@@ -11,32 +11,36 @@
 #define PNGRW_PALSORT_BY_FREQUENCY
 
 #if defined(_WIN32) && !defined(__GNUC__) && !defined(PNGRW_WINDOWS)
-#define PNGRW_WINDOWS
+# define PNGRW_WINDOWS
 #endif
 
 #ifdef PNGRW_WINDOWS
-#include <tchar.h>
+# include <tchar.h>
 #endif
 
-#include "../config.h"
+#include <config.h>
+
 #include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-
-#ifdef PNGRW_WINDOWS
-#include <io.h>
-#include <fcntl.h>
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+# include <string.h>
 #endif
 
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#define OPTEND -1
-#else
-#define OPTEND EOF
+#ifdef PNGRW_WINDOWS
+# include <io.h>
+# include <fcntl.h>
 #endif
 
 #ifdef HAVE_GETOPT_H
-#include <getopt.h>
+# include <getopt.h>
+#endif
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+# define OPTEND -1
+#else
+# define OPTEND EOF
 #endif
 
 #ifdef __MINGW32__
@@ -48,13 +52,13 @@ extern int optind;
 #include "libpngrecolor.h"
 
 #ifndef PNGRW_WINDOWS
-#define TCHAR char
-#define _T
-#define _ftprintf fprintf
-#define _tcscmp   strcmp
-#define _fileno   fileno
-#define _tmain    main
-#define _isatty   isatty
+# define TCHAR char
+# define _T
+# define _ftprintf fprintf
+# define _tcscmp   strcmp
+# define _fileno   fileno
+# define _tmain    main
+# define _isatty   isatty
 #endif
 
 static void my_error_fn(struct pngrw_ctx *ctx, const PNGRW_CHAR *msg)
