@@ -1,6 +1,6 @@
 /* filehash:  Print various hash digests and filesizes for specified files.
 
-   Copyright (C) 2004-2018 by Brian Lindholm.
+   Copyright (C) 2004-2020 by Brian Lindholm.
    This file is part of the littleutils utility set.
 
    The filehash utility is free software; you can redistribute it and/or modify
@@ -17,40 +17,49 @@
    the littleutils.  If not, see <https://www.gnu.org/licenses/>. */
 
 
-#include "../config.h"
+#include <config.h>
+
 #include <limits.h>
 #include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+# include <string.h>
+#endif
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
+# include <sys/stat.h>
+#endif
 
 #ifdef HAVE_GETOPT_H
-#include <getopt.h>
+# include <getopt.h>
+#endif
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+# define OPTEND -1
+#else
+# define OPTEND EOF
 #endif
 
 #if HAVE_INTTYPES_H
-#include <inttypes.h>
-#endif
-
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#define OPTEND -1
-#else
-#define OPTEND EOF
+# include <inttypes.h>
 #endif
 
 #ifdef MSDOS
-#include "io.h"
+# include "io.h"
 #endif
 
 #include "md5.h"
 #include "sha1.h"
 #include "sha256.h"
 #include "sha512.h"
+#include "b2sum.h"
 
 #ifdef HAVE_FSEEKO
-#define fseek(a,b,c) fseeko((a),(off_t)(b),(c))
+# define fseek(a,b,c) fseeko((a),(off_t)(b),(c))
 #endif
 
 #ifdef __MINGW32__
@@ -64,7 +73,7 @@ unsigned short _djstat_flags = 63;
 #endif
 
 #ifndef PATH_MAX
-#define PATH_MAX 256
+# define PATH_MAX 256
 #endif
 
 char *sizefmt = (sizeof (off_t) <= sizeof (long) ? "%lu" : "%llu");
@@ -76,22 +85,23 @@ help (FILE *where)
   fprintf (where,
     "filehash " PACKAGE_VERSION "\n"
     "usage: filehash [ -1(MD5) ] [ -2(SHA1) ] [ -3(SHA224) ] [ -4(SHA256) ]\n"
-    "         [ -5(SHA384) ] [ -6(SHA512) ] [-c(lassic)] [ -f file_list ]\n"
-    "         [ -h(elp) ] [ -n byte_count ] [ -p(ipe) ] [ -q(uiet) ] [ -s(ize) ]\n"
-    "         file...\n");
+    "         [ -5(SHA384) ] [ -6(SHA512) ] [ -7(BLAKE2B_256)] [ -8(BLAKE2B_256)]\n"
+    "         [-c(lassic)] [ -f file_list ] [ -h(elp) ] [ -n byte_count ]\n"
+    "         [ -p(ipe) ] [ -q(uiet) ] [ -s(ize) ] file...\n");
 }
 
 
 static void
 print_filehash (char *filename, off_t read_bytes, int print_size, int run_md5,
   int run_sha1, int run_sha224, int run_sha256, int run_sha384, int run_sha512,
-  int verbose, int classic)
+  int run_blake2b_256, int run_blake2b_512, int verbose, int classic)
 {
   FILE *file;
   int i, not_first, rc;
   struct stat file_stats;
   unsigned char md5result[16], sha1result[20], sha224result[28],
-                sha256result[32], sha384result[48], sha512result[64];
+                sha256result[32], sha384result[48], sha512result[64],
+                blake2b_256result[32], blake2b_512result[64];
 
   if (stat (filename, &file_stats))
     fprintf (stderr, "filehash error: can't stat %s\n", filename);
@@ -157,6 +167,24 @@ print_filehash (char *filename, off_t read_bytes, int print_size, int run_md5,
                 "filehash error: sha512_stream failed on %s\n", filename);
             not_first = 1;
           }
+          if (run_blake2b_256) {
+            if (not_first)
+              (void) fseek (file, (off_t) 0, 0);
+            rc = blake2b_stream (file, blake2b_256result, 32, read_bytes);
+            if (rc)
+              fprintf (stderr,
+                "filehash error: sha384_stream failed on %s\n", filename);
+            not_first = 1;
+          }
+          if (run_blake2b_512) {
+            if (not_first)
+              (void) fseek (file, (off_t) 0, 0);
+            rc = blake2b_stream (file, blake2b_512result, 64, read_bytes);
+            if (rc)
+              fprintf (stderr,
+                "filehash error: sha512_stream failed on %s\n", filename);
+            not_first = 1;
+          }
           (void) fclose (file);
           not_first = 0;
           if ((verbose == 1) && (classic == 0)) {
@@ -258,6 +286,32 @@ print_filehash (char *filename, off_t read_bytes, int print_size, int run_md5,
                 fprintf (stdout, "%02x", (unsigned int) sha512result[i]);
             }
           }
+          if (run_blake2b_256) {
+            if (classic) {
+              for (i = 0; i < 32; ++i)
+                fprintf (stdout, "%02x", (unsigned int) blake2b_256result[i]);
+              fprintf (stdout, "  %s\n", filename);
+            }
+            else {
+              if (not_first)
+                fprintf (stdout, "\t");
+              for (i = 0; i < 32; ++i)
+                fprintf (stdout, "%02x", (unsigned int) blake2b_256result[i]);
+            }
+          }
+          if (run_blake2b_512) {
+            if (classic) {
+              for (i = 0; i < 64; ++i)
+                fprintf (stdout, "%02x", (unsigned int) blake2b_512result[i]);
+              fprintf (stdout, "  %s\n", filename);
+            }
+            else {
+              if (not_first)
+                fprintf (stdout, "\t");
+              for (i = 0; i < 64; ++i)
+                fprintf (stdout, "%02x", (unsigned int) blake2b_512result[i]);
+            }
+          }
           if (classic == 0)
             fprintf (stdout, "\n");
         }
@@ -271,25 +325,28 @@ main (int argc, char **argv)
   FILE *infile;
   char filename[PATH_MAX], *listname, *newline, *rc;
   int argn, classic, opt, print_size, run_md5, run_sha1, run_sha224,
-      run_sha256, run_sha384, run_sha512, use_file, use_pipe, verbose;
-  off_t read_bytes;
+      run_sha256, run_sha384, run_sha512, run_blake2b_256, run_blake2b_512,
+      use_file, use_pipe, verbose;
+  off_t read_bytes, tmp_bytes;
 
   /* parse options */
 
   classic = 0;
   listname = "";
   print_size = 0;
-  read_bytes = 0;
+  read_bytes = -1;
   run_md5 = 0;
   run_sha1 = 0;
   run_sha224 = 0;
   run_sha256 = 0;
   run_sha384 = 0;
   run_sha512 = 0;
+  run_blake2b_256 = 0;
+  run_blake2b_512 = 0;
   use_file = 0;
   use_pipe = 0;
   verbose = 0;
-  while ((opt = getopt (argc, argv, "123456cf:hpn:qsv")) != OPTEND)
+  while ((opt = getopt (argc, argv, "12345678cf:hpn:qsv")) != OPTEND)
     switch (opt)
       {
       case '1':
@@ -310,6 +367,12 @@ main (int argc, char **argv)
       case '6':
         run_sha512 = 1;
         break;
+      case '7':
+        run_blake2b_256 = 1;
+        break;
+      case '8':
+        run_blake2b_512 = 1;
+        break;
       case 'c':
         classic = 1;
         break;
@@ -321,8 +384,10 @@ main (int argc, char **argv)
         help (stdout);
         return (0);
       case 'n':
-        read_bytes = (sizeof (off_t) <= sizeof (long) ? atol(optarg) : atoll(optarg));
-        if (read_bytes < 0)
+        tmp_bytes = (sizeof (off_t) <= sizeof (long) ? atol(optarg) : atoll(optarg));
+        if (tmp_bytes > 0)
+          read_bytes = tmp_bytes;
+        else
           read_bytes = 0;
         break;
       case 'p':
@@ -356,8 +421,9 @@ main (int argc, char **argv)
       else
         verbose = -1;
     }
-  if ((run_md5 + run_sha1 + run_sha224 + run_sha256 + run_sha384 + run_sha512) == 0)
-    run_sha256 = 1;
+  if ((run_md5 + run_sha1 + run_sha224 + run_sha256 + run_sha384 + run_sha512 +
+    run_blake2b_256 + run_blake2b_512) == 0)
+      run_sha256 = 1;
 
   /* process files in listed in file specified by -f option */
 
@@ -379,7 +445,7 @@ main (int argc, char **argv)
                   if (strlen (filename) != 0)
                     print_filehash (filename, read_bytes, print_size, run_md5,
                       run_sha1, run_sha224, run_sha256, run_sha384, run_sha512,
-                      verbose, classic);
+                      run_blake2b_256, run_blake2b_512, verbose, classic);
                 }
             }
           (void) fclose (infile);
@@ -400,7 +466,7 @@ main (int argc, char **argv)
             if (strlen (filename) != 0)
               print_filehash (filename, read_bytes, print_size, run_md5,
                 run_sha1, run_sha224, run_sha256, run_sha384, run_sha512,
-                verbose, classic);
+                run_blake2b_256, run_blake2b_512, verbose, classic);
           }
       }
 
@@ -408,7 +474,8 @@ main (int argc, char **argv)
 
   for (argn = optind; argn < argc; argn++)
     print_filehash (argv[argn], read_bytes, print_size, run_md5, run_sha1,
-      run_sha224, run_sha256, run_sha384, run_sha512, verbose, classic);
+      run_sha224, run_sha256, run_sha384, run_sha512, run_blake2b_256,
+      run_blake2b_512, verbose, classic);
 
   /* indicate successful finish */
 
