@@ -1,8 +1,8 @@
 /* lrealpath:  Prints the real path of the specified files.  This is intended
-   to resolve symbolic links on Unix machines.  Amazingly, it works on DOS
-   machines too.
+   to resolve symbolic links on Unix machines.  Remarkably, it works on DOS
+   and Windows machines also.
 
-   Copyright (C) 2004-2013 by Brian Lindholm.
+   Copyright (C) 2004-2020 by Brian Lindholm.
    This file is part of the littleutils utility set.
 
    The lrealpath utility is free software; you can redistribute it and/or
@@ -19,24 +19,28 @@
    the littleutils.  If not, see <https://www.gnu.org/licenses/>. */
 
 
-#include "../config.h"
+#include <config.h>
+
 #include <limits.h>
 #include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+# include <string.h>
+#endif
 #ifdef DJGPP
-#include <sys/stat.h>
+# include <sys/stat.h>
 #endif
 
 #ifdef HAVE_GETOPT_H
-#include <getopt.h>
+# include <getopt.h>
 #endif
-
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#define OPTEND -1
+# include <unistd.h>
+# define OPTEND -1
 #else
-#define OPTEND EOF
+# define OPTEND EOF
 #endif
 
 #ifdef __MINGW32__
@@ -46,7 +50,7 @@ extern int optind;
 #endif
 
 #ifndef PATH_MAX
-#define PATH_MAX 256
+# define PATH_MAX 256
 #endif
 
 
