@@ -1,6 +1,6 @@
 /* randomize:  Randomizes lines from a file or from stdin.
 
-   Copyright (C) 2004-2018 by Brian Lindholm.
+   Copyright (C) 2004-2020 by Brian Lindholm.
    This file is part of the littleutils utility set.
 
    The randomize utility is free software; you can redistribute it and/or
@@ -17,23 +17,29 @@
    the littleutils.  If not, see <https://www.gnu.org/licenses/>. */
 
 
-#include "../config.h"
+#include <config.h>
+
 #include <fcntl.h>
 #include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+# include <string.h>
+#endif
 #include <time.h>
-#include <sys/stat.h>
-
-#ifdef HAVE_GETOPT_H
-#include <getopt.h>
+#ifdef HAVE_SYS_STAT_H
+# include <sys/stat.h>
 #endif
 
+#ifdef HAVE_GETOPT_H
+# include <getopt.h>
+#endif
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#define OPTEND -1
+# include <unistd.h>
+# define OPTEND -1
 #else
-#define OPTEND EOF
+# define OPTEND EOF
 #endif
 
 #ifdef __MINGW32__
@@ -48,11 +54,11 @@ unsigned short _djstat_flags = 63;
 #endif
 
 #ifndef BLOCKSIZE
-#define BLOCKSIZE 8192
+# define BLOCKSIZE 8192
 #endif
 
 #ifndef PATH_MAX
-#define PATH_MAX 256
+# define PATH_MAX 256
 #endif
 
 
